

/*
 * helloworld.c: simple test application
 *
 * This application configures UART 16550 to baud rate 9600.
 * PS7 UART (Zynq) is not initialized by this application, since
 * bootrom/bsp configures it to baud rate 115200
 *
 * ------------------------------------------------
 * | UART TYPE   BAUD RATE                        |
 * ------------------------------------------------
 *   uartns550   9600
 *   uartlite    Configurable only in HW design
 *   ps7_uart    115200 (configured by bootrom/bsp)
 */

#include <stdio.h>
#include "platform.h"
#include <xil_io.h>



#define C_BASE_ADDR 0x81600000
#define TX_FIFO_ADDR C_BASE_ADDR+0x108
#define RX_FIFO_ADDR C_BASE_ADDR+0x10C
#define CR_ADDR C_BASE_ADDR+0x100
#define SR_ADDR C_BASE_ADDR+0x104
#define RC_FIFO_PIRQ_ADDR C_BASE_ADDR+0x120
#define SLAVE_ADDR_REG C_BASE_ADDR+0x110
#define RC_FIFO_OCY C_BASE_ADDR+118
#define TX_FIFO_OCY C_BASE_ADDR+114
#define INTERRUPT_STATUS_REG C_BASE_ADDR+020
#define GLOBAL_INTERRUPT_REG C_BASE_ADDR+01C
#define INTERRUPT_ENABLE_REG C_BASE_ADDR+028

void print(char *str);

void test(){

	u32 interrupt_reg;
	u32 status_reg;
	u32 tx_fifo;
	u32 rx_fifo;
	u32 control_reg;

	/////////////////////////////////////////////////////
	//****************master transmitter***************//
	/////////////////////////////////////////////////////

	//value check
		status_reg=Xil_In32(SR_ADDR);
		control_reg=Xil_In32(CR_ADDR);
		interrupt_reg=Xil_In32(INTERRUPT_STATUS_REG);
		tx_fifo=Xil_In32(TX_FIFO_ADDR);
		rx_fifo=Xil_In32(RX_FIFO_ADDR);

	//wirte address to tx_fifo (start bit, address, write)
		Xil_Out32(TX_FIFO_ADDR,  (0x100|((0x00000040<<1)&0xFE)|0x0));

	//value check
		status_reg=Xil_In32(SR_ADDR);
		control_reg=Xil_In32(CR_ADDR);
		interrupt_reg=Xil_In32(INTERRUPT_STATUS_REG);
		tx_fifo=Xil_In32(TX_FIFO_ADDR);
		rx_fifo=Xil_In32(RX_FIFO_ADDR);

	//write data to tx_fifo (stop bit, 0xE3=trigger temperature measurement)
		Xil_Out32(TX_FIFO_ADDR, 0x2E3);

	//value check
		status_reg=Xil_In32(SR_ADDR);
		control_reg=Xil_In32(CR_ADDR);
		interrupt_reg=Xil_In32(INTERRUPT_STATUS_REG);
		tx_fifo=Xil_In32(TX_FIFO_ADDR);
		rx_fifo=Xil_In32(RX_FIFO_ADDR);

	//control register set (TX=1, MSMS=1, CR_enable=1)
		Xil_Out32(CR_ADDR, ((0x00000008)|(0x00000004)|(0x00000001)));

	//value check
		status_reg=Xil_In32(SR_ADDR);
		control_reg=Xil_In32(CR_ADDR);
		interrupt_reg=Xil_In32(INTERRUPT_STATUS_REG);
		tx_fifo=Xil_In32(TX_FIFO_ADDR);
		rx_fifo=Xil_In32(RX_FIFO_ADDR);


	/////////////////////////////////////////////////////
	//******************master receiver****************//
	/////////////////////////////////////////////////////

	//wirte address to tx_fifo (start bit, address, read)
		Xil_Out32(TX_FIFO_ADDR,  (0x100|((0x00000040<<1)&0xFE)|0x1));

	//value check
		status_reg=Xil_In32(SR_ADDR);
		control_reg=Xil_In32(CR_ADDR);
		interrupt_reg=Xil_In32(INTERRUPT_STATUS_REG);
		tx_fifo=Xil_In32(TX_FIFO_ADDR);
		rx_fifo=Xil_In32(RX_FIFO_ADDR);



}

void init(){

	//RC_FIFO set = 0x0f
		Xil_Out32(RC_FIFO_PIRQ_ADDR, 0x0f);

	//set slave address register
		Xil_Out32(SLAVE_ADDR_REG, 0x40);

	//reset Tx_FIFO
		Xil_Out32(CR_ADDR, 0x02);

	//enable IIC
		Xil_Out32(CR_ADDR, 0x01);

	//interrupt enable
		Xil_Out32(C_BASE_ADDR+0x01C, 0x80000000);
		Xil_Out32(C_BASE_ADDR+0x028, 0xff);

}

int main()
{
		init_platform();

		print("Hello World\n\r");
		init();
		test();

    return 0;
}
